const fs = require('fs');
const { exec } = require('child_process');

// Function to increment the version in package.json
function incrementPackage() {
    try {
        // Read package.json
        const packageJson = JSON.parse(fs.readFileSync('package.json', 'utf8'));

        // Extract package name
        const packageName = packageJson.name;

        // Extract package version
        const packageVersion = packageJson.version;

        // Split the package name by '-' to get the base name
        const nameParts = packageName.split('-');

        // Check if the last part of the name is a number
        const lastPart = nameParts[nameParts.length - 1];
        const isNumeric = !isNaN(lastPart);

        // If the last part is a number, increment it; otherwise, append '1'
        if (isNumeric) {
            nameParts[nameParts.length - 1] = parseInt(lastPart) + 1;
        } else {
            nameParts.push('1');
        }

        // Update the package name with the incremented number
        const updatedPackageName = nameParts.join('-');

        // Update the package name in package.json
        packageJson.name = updatedPackageName;

        // Write updated package.json
        fs.writeFileSync('package.json', JSON.stringify(packageJson, null, 2));

        console.log('Package name incremented to', updatedPackageName);
    } catch (error) {
        console.error('Error incrementing package name:', error);
    }
}

// Function to publish the package
function publishPackage() {
    exec('npm publish --access public', (error, stdout, stderr) => {
        if (error) {
            console.error('Error publishing package:', error);
            return;
        }
        console.log(stdout);
        console.error(stderr);
    });
}

// Function to run increment and publish in a loop
function runLoop() {
    // Increment package name and publish package
    incrementPackage();
    publishPackage();

    // Delay for 1 minute (adjust as needed)
    setTimeout(runLoop, 60000/10); // 60000 milliseconds = 1 minute
}

// Start the loop
runLoop();
